@@ -35,7 +35,7 @@ class EmailForm(models.Model):
         ordering = ('-starts_at',)
 
     title = models.CharField(max_length=80)
-    slug = models.SlugField(unique=True)
+    slug = models.SlugField()
     description = models.TextField(blank=True)
     starts_at = models.DateTimeField(default=datetime.datetime.now)
     is_published = models.BooleanField(default=False)
@@ -47,6 +47,9 @@ class EmailForm(models.Model):
         max_length=300)
     site = models.ForeignKey(Site)
 
+    class Meta:
+        unique_together = (('slug', 'site'),)
+
     def __unicode__(self):
         return self.title
 
